==> walletpackage-1.0.7.tar.gz: test/walletpackage_test.dart <==
import 'package:walletpackage/ethereumTransaction.dart';
import 'package:walletpackage/walletpackage.dart';

void main() {
//  testCreateMnemonicAndAddress();
//  testChangePassword();
//  testImportMnemonicAndAddress();

  testCreateErc20Transaction().then((value) => {testSignTransaction(value)});
}

Future<void> testSignTransaction(Object transaction) async {
  String type = 'EUSDT';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"692ef2b50834aec8acc19eef2e950290"},"ciphertext":"9931adf3f5be22ed89575fa6a9aba69aa72c9238409e0bcb3af10fde66a4b877ca019fb1b99727ef4442a9a71ac62ec415c16f7137ed118da26a5dd4c654ef30","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"e593b8b70e77b61382f5082aab36923bc54a57c72b55f45ee4991727af904b48"},"mac":"571d57d591e014ef139a5b5ff64c1b32b93b3881b96c27bc1425cde5c67c2c9e"},"id":"deb6f66a-733a-402d-81f5-9b9ab63ab68d","version":3}';
  String passwd = '123456';
  String result = await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateErc20Transaction() async {
  String from = '0x95463fb4D864F4bbCeab959b5B0b5F4C3A024108';
  String to = '0xa3b65Ba11F77F4B53A691fd722373D038418cDCE';
  num value = 1;
  int gasPrice = 10;
  int nonce = 0;
  var transaction = await EthereumTransaction.createErc20Transaction(
      'EUSDT', from, to, value, gasPrice, nonce);
//  print(hex);
  return transaction;
}

Future<void> testImportMnemonicAndAddress() async {
  String mnemonic =
      'diagram frame frequent rain episode convince indoor thank retreat wheat vapor unusual';
  //String passwd = '123456';
  WalletData result = await WalletProxy.importMnemonicAndAddress(mnemonic);
  print(result);
}

Future<void> testChangePassword() async {
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"6c02c795e7b3df21d7b88dee53a3e6bd"},"ciphertext":"658f02c82d551eae5bcec7beb7952d0ad8191f697c6b46e563179c2d8f4868304e08f60c0bd9c566c4aec35091fb4d4502c49f3f1d45d35279af68b84935f563","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"9bd25b612f58d361b1f69728dc3ee5fe3f22775ddc6a29531111b0be74a6e9b1"},"mac":"c2182716ff042d48d587a727bc9ca338bb27e902ed121acf7b3a9446d9aae0b7"},"id":"0bb8fb48-a218-44b2-97b7-a9d263bb71de","version":3}';
  String passwd = '123456';
  String newPasswd = '456789';
  String newKeystore = await WalletProxy.changePassword(keystore, passwd, newPasswd);
  print(newKeystore);
}

Future<void> testCreateMnemonicAndAddress() async {
  WalletData walletData = await WalletProxy.createMnemonicAndAddress('123456');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
}

==> walletpackage-1.0.8.tar.gz: test/walletpackage_test.dart <==
import 'package:walletpackage/bitcoinTransaction.dart';
import 'package:walletpackage/ethereumTransaction.dart';
import 'package:walletpackage/walletpackage.dart';

void main() {
//  testCreateMnemonicAndAddress();
//  testChangePassword();
//  testImportMnemonicAndAddress();

//  testCreateErc20Transaction().then((value) => {testSignEusdtTransaction(value)});
  testCreateOmniTransaction().then((value) => {testSignUsdtTransaction(value)});
}

Future<void> testSignUsdtTransaction(Object transaction) async {
  String type = 'USDT';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"692ef2b50834aec8acc19eef2e950290"},"ciphertext":"9931adf3f5be22ed89575fa6a9aba69aa72c9238409e0bcb3af10fde66a4b877ca019fb1b99727ef4442a9a71ac62ec415c16f7137ed118da26a5dd4c654ef30","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"e593b8b70e77b61382f5082aab36923bc54a57c72b55f45ee4991727af904b48"},"mac":"571d57d591e014ef139a5b5ff64c1b32b93b3881b96c27bc1425cde5c67c2c9e"},"id":"deb6f66a-733a-402d-81f5-9b9ab63ab68d","version":3}';
  String passwd = '123456';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateOmniTransaction() async {
  String from = '1NTpKrwECww7fcGrK2JUei9Uh5R8nazttc';
  String to = '1HBjHDyMopmifhdj7gSg9WJPewp12rTnPJ';
  num value = 0.001;
  num fee = 0.005;
  var transaction =
      await BitcoinTransaction.createOmniTransaction(from, to, value, fee);
  return transaction;
}

Future<void> testSignEusdtTransaction(Object transaction) async {
  String type = 'EUSDT';
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"692ef2b50834aec8acc19eef2e950290"},"ciphertext":"9931adf3f5be22ed89575fa6a9aba69aa72c9238409e0bcb3af10fde66a4b877ca019fb1b99727ef4442a9a71ac62ec415c16f7137ed118da26a5dd4c654ef30","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"e593b8b70e77b61382f5082aab36923bc54a57c72b55f45ee4991727af904b48"},"mac":"571d57d591e014ef139a5b5ff64c1b32b93b3881b96c27bc1425cde5c67c2c9e"},"id":"deb6f66a-733a-402d-81f5-9b9ab63ab68d","version":3}';
  String passwd = '123456';
  String result =
      await WalletProxy.signTransaction(type, keystore, passwd, transaction);
  print(result);
}

Future<Object> testCreateErc20Transaction() async {
  String from = '0x95463fb4D864F4bbCeab959b5B0b5F4C3A024108';
  String to = '0xa3b65Ba11F77F4B53A691fd722373D038418cDCE';
  num value = 1;
  int gasPrice = 10;
  int nonce = 0;
  var transaction = await EthereumTransaction.createErc20Transaction(
      from, to, value, gasPrice, nonce);
  return transaction;
}

Future<void> testImportMnemonicAndAddress() async {
  String mnemonic =
      'diagram frame frequent rain episode convince indoor thank retreat wheat vapor unusual';
  WalletData walletData = await WalletProxy.importMnemonicAndAddress(mnemonic);
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
}

Future<void> testChangePassword() async {
  String keystore =
      '{"crypto":{"cipher":"aes-128-ctr","cipherparams":{"iv":"6c02c795e7b3df21d7b88dee53a3e6bd"},"ciphertext":"658f02c82d551eae5bcec7beb7952d0ad8191f697c6b46e563179c2d8f4868304e08f60c0bd9c566c4aec35091fb4d4502c49f3f1d45d35279af68b84935f563","kdf":"scrypt","kdfparams":{"dklen":32,"n":8192,"r":8,"p":1,"salt":"9bd25b612f58d361b1f69728dc3ee5fe3f22775ddc6a29531111b0be74a6e9b1"},"mac":"c2182716ff042d48d587a727bc9ca338bb27e902ed121acf7b3a9446d9aae0b7"},"id":"0bb8fb48-a218-44b2-97b7-a9d263bb71de","version":3}';
  String passwd = '123456';
  String newPasswd = '456789';
  String newKeystore =
      await WalletProxy.changePassword(keystore, passwd, newPasswd);
  print(newKeystore);
}

Future<void> testCreateMnemonicAndAddress() async {
  WalletData walletData = await WalletProxy.createMnemonicAndAddress('123456');
  print(walletData.mnemonic);
  print(walletData.keystore);
  print(walletData.addresses);
}
